@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  LibreDWG - free implementation of the DWG file format                    */
 /*                                                                           */
-/*  Copyright (C) 2009-2019 Free Software Foundation, Inc.                   */
+/*  Copyright (C) 2009-2023 Free Software Foundation, Inc.                   */
 /*  Copyright (C) 2010 Thien-Thi Nguyen                                      */
 /*                                                                           */
 /*  This library is free software, licensed under the terms of the GNU       */
@@ -26,7 +26,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <libps/pslib.h>
-#include <getopt.h>
+#include "my_getopt.h"
 
 #include <dwg.h>
 #include <dwg_api.h>
@@ -74,12 +74,19 @@ help (void)
 /* handles r2007 wide chars (=> utf8) */
 static int
 set_info (PSDoc *restrict ps, Dwg_Data *restrict dwg, const char *restrict key,
-          BITCODE_TU restrict text)
+          BITCODE_T16 restrict text)
 {
   int ret = 0;
-  if (text)
+  if (!text)
+    return 0;
+  if (dwg->header.from_version < R_2007)
     {
-      char *u8 = bit_convert_TU (text);
+      PS_set_info (ps, key, text);
+      ret = 1;
+    }
+  else
+    {
+      char *u8 = bit_convert_TU ((BITCODE_TU)text);
       if (u8 && strlen (u8))
         {
           PS_set_info (ps, key, u8);
@@ -114,9 +121,10 @@ create_postscript (Dwg_Data *dwg, char *output)
     }
 
   PS_set_info (ps, "Creator", "dwg2ps " PACKAGE_VERSION);
+  (void)set_info (ps, dwg, "Subject", dwg->summaryinfo.SUBJECT);
   (void)set_info (ps, dwg, "Author", dwg->summaryinfo.LASTSAVEDBY);
   if (set_info (ps, dwg, "Title", dwg->summaryinfo.TITLE))
-    set_info (ps, dwg, "Keywords", dwg->summaryinfo.KEYWORDS);
+    (void)set_info (ps, dwg, "Keywords", dwg->summaryinfo.KEYWORDS);
   else
     {
       PS_set_info (ps, "Title", output);
@@ -156,11 +164,11 @@ create_postscript (Dwg_Data *dwg, char *output)
   for (i = 0; i < dwg->num_objects; i++)
     {
       Dwg_Object *obj = &dwg->object[i];
-      if (obj->type == DWG_SUPERTYPE_OBJECT) // no entity
+      if (obj->supertype == DWG_SUPERTYPE_OBJECT) // no entity
         continue;
       // if (obj->tio.entity->entity_mode == 0) // belongs to block
       //  continue;
-      if (obj->type == DWG_TYPE_LINE)
+      if (obj->fixedtype == DWG_TYPE_LINE)
         {
           Dwg_Entity_LINE *line = obj->tio.entity->tio.LINE;
           BITCODE_3DPOINT start, end;
@@ -171,11 +179,11 @@ create_postscript (Dwg_Data *dwg, char *output)
           PS_lineto (ps, (float)end.x, (float)end.y);
           PS_stroke (ps);
         }
-      else if (obj->type == DWG_TYPE_POLYLINE_2D)
+      else if (obj->fixedtype == DWG_TYPE_POLYLINE_2D)
         {
           int error;
           BITCODE_RL j,
-            numpts = dwg_object_polyline_2d_get_numpoints (obj, &error);
+              numpts = dwg_object_polyline_2d_get_numpoints (obj, &error);
           dwg_point_2d *pts = dwg_object_polyline_2d_get_points (obj, &error);
           Dwg_Entity_POLYLINE_2D *pline = obj->tio.entity->tio.POLYLINE_2D;
           if (numpts && !error)
@@ -202,7 +210,7 @@ create_postscript (Dwg_Data *dwg, char *output)
               free (pts);
             }
         }
-      else if (obj->type == DWG_TYPE_LWPOLYLINE)
+      else if (obj->fixedtype == DWG_TYPE_LWPOLYLINE)
         {
           int error;
           Dwg_Entity_LWPOLYLINE *pline = obj->tio.entity->tio.LWPOLYLINE;
@@ -230,20 +238,19 @@ create_postscript (Dwg_Data *dwg, char *output)
                   PS_lineto (ps, (float)pt0.x, (float)pt0.y);
                   PS_stroke (ps);
                 }
-                
+
               free (pts);
             }
         }
-      else if (obj->type == DWG_TYPE_ARC)
+      else if (obj->fixedtype == DWG_TYPE_ARC)
         {
           Dwg_Entity_ARC *arc = obj->tio.entity->tio.ARC;
           BITCODE_3DPOINT center;
           transform_OCS (&center, arc->center, arc->extrusion);
-          PS_arc (ps, (float)center.x, (float)center.y,
-                  (float)arc->radius, (float)arc->start_angle,
-                  (float)arc->end_angle);
+          PS_arc (ps, (float)center.x, (float)center.y, (float)arc->radius,
+                  (float)arc->start_angle, (float)arc->end_angle);
         }
-      else if (obj->type == DWG_TYPE_CIRCLE)
+      else if (obj->fixedtype == DWG_TYPE_CIRCLE)
         {
           Dwg_Entity_CIRCLE *circle = obj->tio.entity->tio.CIRCLE;
           BITCODE_3DPOINT center;
