@@ -24,5 +24,13 @@
 #include "bits.h"
 
 EXPORT void dwg_free_eed (Dwg_Object *obj);
+/* Needed when we cast types.
+   By fixedtype, not dxfname. */
+EXPORT void dwg_free_object_private (Dwg_Object *obj);
+
+int dwg_free_variable_type_private (Dwg_Object *restrict obj);
+int dwg_free_variable_type (Dwg_Data *restrict dwg, Dwg_Object *restrict obj);
+int dwg_free_variable_no_class (Dwg_Data *restrict dwg,
+                                Dwg_Object *restrict obj);
 
 #endif
