@@ -11,16 +11,17 @@ api_process (dwg_object *obj)
   BITCODE_BS class_version;
 
   Dwg_Version_Type dwg_version = obj->parent->header.version;
-  dwg_obj_assocdimdependencybody *_obj = dwg_object_to_ASSOCDIMDEPENDENCYBODY (obj);
+  dwg_obj_assocdimdependencybody *_obj
+      = dwg_object_to_ASSOCDIMDEPENDENCYBODY (obj);
 
   // AcDbAssocDependencyBody:
   CHK_ENTITY_TYPE (_obj, ASSOCDIMDEPENDENCYBODY, adb_version, BL);
-  CHK_ENTITY_MAX  (_obj, ASSOCDIMDEPENDENCYBODY, adb_version, BL, 1);
+  CHK_ENTITY_MAX (_obj, ASSOCDIMDEPENDENCYBODY, adb_version, BL, 1);
   // AcDbImpAssocDimDependencyBodyBase
   CHK_ENTITY_TYPE (_obj, ASSOCDIMDEPENDENCYBODY, dimbase_version, BL);
-  CHK_ENTITY_MAX  (_obj, ASSOCDIMDEPENDENCYBODY, dimbase_version, BL, 1);
+  CHK_ENTITY_MAX (_obj, ASSOCDIMDEPENDENCYBODY, dimbase_version, BL, 1);
   CHK_ENTITY_UTF8TEXT (_obj, ASSOCDIMDEPENDENCYBODY, name);
   // AcDbAssocDimDependencyBody
   CHK_ENTITY_TYPE (_obj, ASSOCDIMDEPENDENCYBODY, class_version, BL);
-  CHK_ENTITY_MAX  (_obj, ASSOCDIMDEPENDENCYBODY, class_version, BL, 1);
+  CHK_ENTITY_MAX (_obj, ASSOCDIMDEPENDENCYBODY, class_version, BL, 1);
 }
