@@ -9,7 +9,6 @@ api_process (dwg_object *obj)
   BLOCKGRIP_fields;
 
   Dwg_Version_Type dwg_version = obj->parent->header.version;
-#ifdef DEBUG_CLASSES
   dwg_obj_blockpolargrip *_obj = dwg_object_to_BLOCKPOLARGRIP (obj);
 
   CHK_EVALEXPR (BLOCKPOLARGRIP);
@@ -21,8 +20,7 @@ api_process (dwg_object *obj)
   // AcDbBlockGrip
   CHK_ENTITY_TYPE (_obj, BLOCKPOLARGRIP, bg_bl91, BL);
   CHK_ENTITY_TYPE (_obj, BLOCKPOLARGRIP, bg_bl92, BL);
-  CHK_ENTITY_3RD  (_obj, BLOCKPOLARGRIP, bg_location);
+  CHK_ENTITY_3RD (_obj, BLOCKPOLARGRIP, bg_location);
   CHK_ENTITY_TYPE (_obj, BLOCKPOLARGRIP, bg_insert_cycling, B);
   CHK_ENTITY_TYPE (_obj, BLOCKPOLARGRIP, bg_insert_cycling_weight, BLd);
-#endif
 }
