@@ -1,8 +1,9 @@
-//This file contains the helper function which are used in the XML Suite
-//to prepare the result
+// This file contains the helper function which are used in the XML Suite
+// to prepare the result
 
 xmlChar *spointprepare (double x, double y, double z);
 xmlChar *doubletochar (double x);
+xmlChar *inttochar (int x);
 xmlChar *spointprepare2 (double x, double y);
 xmlChar *doubletohex (double handle);
 
@@ -13,9 +14,9 @@ xmlChar *doubletohex (double handle);
  *
  *  To emit this in the XML file
  *
- *  @param double x The X Co-ordinate
- *  @param double y The Y Co-ordinate
- *  @param double z The Z Co-ordinate
+ *  @param double x The X coordinate
+ *  @param double y The Y coordinate
+ *  @param double z The Z coordinate
  *
  *  @return xmlChar* Converted string in the specified pattern
  */
@@ -27,22 +28,23 @@ spointprepare (double x, double y, double z)
 
   // Allocating memory for the string
   result = malloc (100 * sizeof (xmlChar));
-  n = sprintf ((char*)result, "(%.4f %.4f %.4f)", x, y, z);
+  n = sprintf ((char *)result, "(%.4f %.4f %.4f)", x, y, z);
 
-  //Check if it was transferred properly
+  // Check if it was transferred properly
   if (n < 0)
     {
-      strcpy ((char*)result, ""); /* return empty string on error */
+      strcpy ((char *)result, ""); /* return empty string on error */
     }
 
   return result;
 }
 
 /*
- * This functions coverts double format in char to be emitted in the XML
+ * This functions converts double format in char to be emitted in the XML
  * @param double x The double digis to be converted in string
  *
- * @return char* Return the converted double in string. Return empty string if error
+ * @return char* Return the converted double in string. Return empty string if
+ * error
  */
 xmlChar *
 doubletochar (double x)
@@ -52,11 +54,34 @@ doubletochar (double x)
 
   /* Allocate memory for the string */
   result = malloc (50 * sizeof (xmlChar));
-  n = sprintf ((char*)result, "%.4f", x);
+  n = sprintf ((char *)result, "%.4f", x);
 
   if (n < 0)
     {
-      strcpy ((char*)result, ""); /* Return empty string on error */
+      strcpy ((char *)result, ""); /* Return empty string on error */
+    }
+
+  return result;
+}
+
+/*
+ * This functions converts int format in char to be emitted in the XML
+ *
+ * @return char* Return the converted double in string. Return empty string if
+ * error
+ */
+xmlChar *
+inttochar (int x)
+{
+  xmlChar *result;
+  int n;
+
+  /* Allocate memory for the string */
+  result = malloc (16 * sizeof (xmlChar));
+  n = sprintf ((char *)result, "%d", x);
+  if (n < 0)
+    {
+      strcpy ((char *)result, ""); /* Return empty string on error */
     }
 
   return result;
@@ -68,10 +93,11 @@ doubletochar (double x)
  *
  * Format: (x y)
  *
- * @param double x The x co-ordinate of the point
- * @param double y The y co-ordinate of the point
+ * @param double x The x coordinate of the point
+ * @param double y The y coordinate of the point
  *
- * @return xmlChar* Returns the string in the given format. Return empty string on error
+ * @return xmlChar* Returns the string in the given format. Return empty string
+ * on error
  */
 xmlChar *
 spointprepare2 (double x, double y)
@@ -81,18 +107,17 @@ spointprepare2 (double x, double y)
 
   /* allocate memory for the string */
   result = malloc (50 * sizeof (xmlChar));
-  n = sprintf ((char*)result, "(%.4f %.4f)", x, y);
+  n = sprintf ((char *)result, "(%.4f %.4f)", x, y);
 
-  //Check if it was transferred properly
+  // Check if it was transferred properly
   if (n < 0)
     {
-      strcpy ((char*)result, ""); /* return empty string on error */
+      strcpy ((char *)result, ""); /* return empty string on error */
     }
 
   return result;
 }
 
-
 /*
  * This function converts double in hex to be used in the XML
  * @param double handle The handle value which is to be converted in Hex
@@ -107,13 +132,13 @@ doubletohex (double handle)
 
   /* allocate memory for the string */
   result = malloc (20 * sizeof (xmlChar));
-  n = sprintf ((char*)result, "%03x", (unsigned int)handle);
+  n = sprintf ((char *)result, "%03X", (unsigned int)handle);
 
-  //Check if it was transferred properly
+  // Check if it was transferred properly
 
   if (n < 0)
     {
-      strcpy ((char*)result, ""); /* return empty string on error */
+      strcpy ((char *)result, ""); /* return empty string on error */
     }
 
   return result;
